---
title: <span class="badge object-type-enum"></span> ScatterShow
---
# <span class="badge object-type-enum"></span> ScatterShow

## Definition

```python
class ScatterShow(enum.StrEnum):
    POINTS = "points"
    LINES = "lines"
    POINTS_AND_LINES = "points+lines"
```
